summaryrefslogtreecommitdiff
path: root/gst/audioresample
diff options
context:
space:
mode:
authorPiotr Fusik <fox@scene.pl>2011-09-13 21:10:43 +0200
committerStefan Sauer <ensonic@users.sf.net>2011-12-02 12:03:27 +0100
commit14644457b06f48b26f32f88ef91e1286a48ebe24 (patch)
tree5216c737500ee2cc4e0032e0c841f6d64660c0cd /gst/audioresample
parent0cce8ab97d614ef53970292bd403e7f4460d79f9 (diff)
downloadgstreamer-plugins-base-14644457b06f48b26f32f88ef91e1286a48ebe24.tar.gz
various: typo fixes
Fix typos in code and docs. Fixes. #658984
Diffstat (limited to 'gst/audioresample')
-rw-r--r--gst/audioresample/gstaudioresample.c6
-rw-r--r--gst/audioresample/resample.c2
2 files changed, 4 insertions, 4 deletions
diff --git a/gst/audioresample/resample.c b/gst/audioresample/resample.c
index 7cc04d66c..490eebcc4 100644
--- a/gst/audioresample/resample.c
+++ b/gst/audioresample/resample.c
@@ -461,7 +461,7 @@ resampler_basic_direct_single (SpeexResamplerState * st,
sum += MULT16_16 (sinc[j], iptr[j]);
/* This code is slower on most DSPs which have only 2 accumulators.
- Plus this this forces truncation to 32 bits and you lose the HW guard bits.
+ Plus this forces truncation to 32 bits and you lose the HW guard bits.
I think we can trust the compiler and let it vectorize and/or unroll itself.
spx_word32_t accum[4] = {0,0,0,0};
for(j=0;j<N;j+=4) {
diff --git a/gst/audioresample/gstaudioresample.c b/gst/audioresample/gstaudioresample.c
index 80988cb7f..418a77c95 100644
--- a/gst/audioresample/gstaudioresample.c
+++ b/gst/audioresample/gstaudioresample.c
@@ -103,7 +103,7 @@ GST_STATIC_CAPS ( \
"signed = (boolean) true" \
)
/* If TRUE integer arithmetic resampling is faster and will be used if appropiate */
#if defined AUDIORESAMPLE_FORMAT_INT
static gboolean gst_audio_resample_use_int = TRUE;
#elif defined AUDIORESAMPLE_FORMAT_FLOAT
@@ -187,7 +187,7 @@ gst_audio_resample_class_init (GstAudioResampleClass * klass)
*
* Length of the resample filter
*
- * Deprectated: Use #GstAudioResample:quality property instead
+ * Deprecated: Use #GstAudioResample:quality property instead
*/
g_object_class_install_property (gobject_class, PROP_FILTER_LENGTH,
g_param_spec_int ("filter-length", "Filter length",
@@ -1554,7 +1554,7 @@ _benchmark_integer_resampling (void)
resample_int_resampler_destroy (stb);
if (av > bv)
- GST_INFO ("Using integer resampler if appropiate: %lf < %lf", bv, av);
+ GST_INFO ("Using integer resampler if appropriate: %lf < %lf", bv, av);
else
GST_INFO ("Using float resampler for everything: %lf <= %lf", av, bv);
@@ -103,7 +103,7 @@ GST_STATIC_CAPS ( \
"signed = (boolean) true" \
)
-/* If TRUE integer arithmetic resampling is faster and will be used if appropiate */
+/* If TRUE integer arithmetic resampling is faster and will be used if appropriate */
#if defined AUDIORESAMPLE_FORMAT_INT
static gboolean gst_audio_resample_use_int = TRUE;